==> benchling_api_client-0.15.0a0-py3-none-any.whl: benchling_api_client/api/dna_oligos/create_dna_oligo.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.bad_request_error import BadRequestError
from ...models.conflict_error import ConflictError
from ...models.dna_oligo import DnaOligo
from ...models.oligo_create import OligoCreate
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    json_body: OligoCreate,
) -> Dict[str, Any]:
    url = "{}/dna-oligos".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": client.get_cookies(),
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[DnaOligo, BadRequestError, ConflictError, None]]:
    if response.status_code == 201:
        response_201 = DnaOligo.from_dict(response.json())

        return response_201
    if response.status_code == 400:
        response_400 = BadRequestError.from_dict(response.json())

        return response_400
    if response.status_code == 409:
        response_409 = ConflictError.from_dict(response.json())

        return response_409
    if response.status_code == 503:
        response_503 = None

        return response_503
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[DnaOligo, BadRequestError, ConflictError, None]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    json_body: OligoCreate,
) -> Response[Union[DnaOligo, BadRequestError, ConflictError, None]]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    response = httpx.post(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
    json_body: OligoCreate,
) -> Optional[Union[DnaOligo, BadRequestError, ConflictError, None]]:
    """ Create a DNA Oligo """

    return sync_detailed(
        client=client,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    json_body: OligoCreate,
) -> Response[Union[DnaOligo, BadRequestError, ConflictError, None]]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
    json_body: OligoCreate,
) -> Optional[Union[DnaOligo, BadRequestError, ConflictError, None]]:
    """ Create a DNA Oligo """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
        )
    ).parsed

==> benchling_api_client-1.1.0a10-py3-none-any.whl: benchling_api_client/api/dna_oligos/create_dna_oligo.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.bad_request_error import BadRequestError
from ...models.dna_oligo import DnaOligo
from ...models.dna_oligo_create import DnaOligoCreate
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    json_body: DnaOligoCreate,
) -> Dict[str, Any]:
    url = "{}/dna-oligos".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": client.get_cookies(),
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[DnaOligo, BadRequestError, None]]:
    if response.status_code == 201:
        response_201 = DnaOligo.from_dict(response.json())

        return response_201
    if response.status_code == 400:
        response_400 = BadRequestError.from_dict(response.json())

        return response_400
    if response.status_code == 503:
        response_503 = None

        return response_503
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[DnaOligo, BadRequestError, None]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    json_body: DnaOligoCreate,
) -> Response[Union[DnaOligo, BadRequestError, None]]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    response = httpx.post(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
    json_body: DnaOligoCreate,
) -> Optional[Union[DnaOligo, BadRequestError, None]]:
    """ Create a DNA Oligo """

    return sync_detailed(
        client=client,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    json_body: DnaOligoCreate,
) -> Response[Union[DnaOligo, BadRequestError, None]]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
    json_body: DnaOligoCreate,
) -> Optional[Union[DnaOligo, BadRequestError, None]]:
    """ Create a DNA Oligo """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
        )
    ).parsed
